#     
#  		CRISPR Cas9
#  		type II-A Cas9 protein from S. pyogenes (SpyCas9)
#     	by Chiamaka Obianyor (Graduate Student in Nick Hud's lab)
#		and Loren Williams
#     	Studying the interactions between CRISPR Cas9 protein
#     	and DNA and RNA 
#     
#----------------------------------------

# delete all objects and reset pymol
reinitialize

# set the background color to white
bg_color white

# make the background transparent for ##ray trace 
set ray_opaque_background, 0

# set the #ray trace mode
set ray_trace_mode, 0

# set the mouse mode for laptop.
set mouse_selection_mode, 1

# run the python program for hydrogen bonding interactions.
run python/list_hbonds.py

#------------load coordinates into objects ----------

load coordinates/5f9r.pdb, coord_cart
create coord_stk, coord_cart 

#load coordinates/4cmq.pdb, coord_Alt
#load coordinates/4ogc.pdb, coord_Alt2

#align coord_Alt,coord_cart
#align coord_Alt2,coord_cart

#------------ set up the representations of the objects ----------

hide everything, coord_*
show cartoon, coord_cart
color cyan, coord_cart

show stick, coord_stk
color wheat, coord_stk and name C*
color blue, coord_stk and name N*
color red, coord_stk and name O*
show spheres, coord_stk
alter coord_stk, vdw=.4 
rebuild

#------------ create RNA and DNA objects----------


create RNA, resi 1-116 and chain A and coord_cart
hide everything, RNA
color wheat, RNA and name C*
color blue, RNA and name N*
color red, RNA and name O*
color yellow, RNA and name P*
show sticks, RNA

create DNA, resi 1-101 and chain C and coord_cart
hide everything, DNA
color cyan, DNA and name C*
color blue, DNA and name N*
color red, DNA and name O*
color yellow, DNA and name P*
show sticks, DNA


create protein_cartoon, resi 3-1361 and chain B and coord_cart
set cartoon_cylindrical_helices,2
color skyblue, protein_cartoon and (resi 1-56) or (resi 718-765) or (resi 918-1099)
color gray80, protein_cartoon and (resi 56-718) 
color green, protein_cartoon and (resi 780-906) 
color yellow, protein_cartoon and (resi 765-780) or (resi 906-918)
color gray40, protein_cartoon and (resi 1099-1368)
hide everything, protein_cartoon
show cartoon, protein_cartoon

create protein_stick, resi 3-1361 and chain B and coord_cart
hide everything, protein_stick
#color wheat, protein_cartoon and name C*
show sticks, protein_stick

create cat_site, (resi 10+762+983+986) and protein_stick

create REC, protein_cartoon and (resi 94-718)
show cartoon, REC

create RUVC,  (resi 1-56 + resi 718-765+ resi 918-1099) and protein_cartoon



#create DNA2, resi 12-101 and chain D and coord_cart
#hide everything, DNA2
#color cyan, DNA2 and name C*
#show sticks, DNA2

create PAM, DNA2 and (resi 21-23) and chain D
show sticks, PAM
color warmpink, PAM


create heteroduplex, (DNA and resi 11-30) or (RNA and resi 1-20) 
hide everything, heteroduplex
show sticks, heteroduplex

create kinkedres, protein_stick and (resi 914-916 or (resi 921 or resi 915))
color green, kinkedres and name C*
color blue, kinkedres and name N*
color red, kinkedres and name O*
color yellow, kinkedres and name P*

#------------ find hydrogen bonds ----------


list_hb DNA, protein_stick, cutoff=3.4, angle=55, hb_list_name = HBonds_DNA_protein
hide labels, HBonds_DNA_protein
color black, HBonds_DNA_protein
set dash_gap, 0.2, HBonds_DNA_protein
set dash_length, 0.10, HBonds_DNA_protein
set dash_width, 4, HBonds_DNA_protein
enable HBonds_DNA_protein
show dashes, HBonds_DNA_protein 


list_hb DNA and resi 11-30, RNA and resi 1-20, cutoff=3.4, angle=55, hb_list_name = HBonds_DNA_RNA
hide labels, HBonds_DNA_RNA
color black, HBonds_DNA_RNA
set dash_gap, 0.2, HBonds_DNA_RNA
set dash_length, 0.10, HBonds_DNA_RNA
set dash_width, 4, HBonds_DNA_RNA
enable HBonds_DNA_RNA
show dashes, HBonds_DNA_RNA 
#show labels, HBonds_DNA_RNA



#------------ Display ----------
disable all
enable RNA
enable DNA
enable protein_cartoon


set_view (\
    -0.385308385,   -0.518024266,   -0.763663709,\
    -0.897288918,    0.403503358,    0.179016188,\
     0.215407148,    0.754208326,   -0.620294333,\
     0.000000000,    0.000000000, -446.201293945,\
   -21.976295471,  -14.113254547,  -73.071487427,\
   371.463806152,  520.938842773,  -20.000000000 )
### cut above here and paste into script ### 
